@@ -56,9 +56,6 @@
 /* globals */
 
 GaimPlugin *handle = NULL;
-#ifdef G_OS_WIN32
-__declspec(dllimport) GSList *unread_message_queue;
-#endif
 
 static gchar* gen_keystr(HotkeyEntry* key, GtkWidget* widget);
 static void grab_keys(GtkWidget* widget);
@@ -79,7 +76,7 @@ static void reconfig_blist(gint action);
 static HotkeyEntry hotkeys[] =
 {
     { N_("Toggle List"), PREF_PATH "use_hotkey_toggle_blist", PREF_PATH "hotkey_toggle_blist", 0, 0, FALSE, 0, 0 },
-    { N_("Read Msg"), PREF_PATH "use_hotkey_read_msg", PREF_PATH "hotkey_read_msg", 0, 0, FALSE, 0, 0 },
+    { N_("Read Message"), PREF_PATH "use_hotkey_read_msg", PREF_PATH "hotkey_read_msg", 0, 0, FALSE, 0, 0 },
     { N_("Show Preferences Dialog"), PREF_PATH "use_hotkey_show_pref", PREF_PATH "hotkey_show_pref", 0, 0, FALSE, 0, 0 },
     { N_("Show Accounts Dialog"), PREF_PATH "use_hotkey_show_acc", PREF_PATH "hotkey_show_acc", 0, 0, FALSE, 0, 0 },
 };
@@ -111,30 +108,16 @@ gen_keystr(HotkeyEntry* key, GtkWidget* widget)
 static GList *
 get_pending_list(guint max)
 {
-	const char *im = gaim_prefs_get_string("/plugins/gtk/docklet/blink_im");
-	const char *chat = gaim_prefs_get_string("/plugins/gtk/docklet/blink_chat");
 	GList *l_im = NULL;
 	GList *l_chat = NULL;
 
-	if (im != NULL && strcmp(im, "always") == 0) {
-		l_im = gaim_gtk_conversations_find_unseen_list(GAIM_CONV_TYPE_IM,
-				GAIM_UNSEEN_TEXT,
-				FALSE, max);
-	} else if (im != NULL && strcmp(im, "hidden") == 0) {
-		l_im = gaim_gtk_conversations_find_unseen_list(GAIM_CONV_TYPE_IM,
-				GAIM_UNSEEN_TEXT,
-				TRUE, max);
-	}
+	l_im = gaim_gtk_conversations_find_unseen_list(GAIM_CONV_TYPE_IM,
+	   					       GAIM_UNSEEN_TEXT,
+						       FALSE, max);
 
-	if (chat != NULL && strcmp(chat, "always") == 0) {
-		l_chat = gaim_gtk_conversations_find_unseen_list(GAIM_CONV_TYPE_CHAT,
-				GAIM_UNSEEN_TEXT,
-				FALSE, max);
-	} else if (chat != NULL && strcmp(chat, "nick") == 0) {
-		l_chat = gaim_gtk_conversations_find_unseen_list(GAIM_CONV_TYPE_CHAT,
-				GAIM_UNSEEN_NICK,
-				FALSE, max);
-	}
+	l_chat = gaim_gtk_conversations_find_unseen_list(GAIM_CONV_TYPE_CHAT,
+		 					 GAIM_UNSEEN_NICK,
+			    			         FALSE, max);
 
 	if (l_im != NULL && l_chat != NULL)
 		return g_list_concat(l_im, l_chat);
@@ -582,7 +565,6 @@ plugin_init(GaimPlugin *plugin)
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 #endif
 
-    plugin->info->dependencies = g_list_append(plugin->info->dependencies, "gtk-docklet");
     /* we have to translate it here as we are in a different textdomain */
     plugin->info->name = _(plugin->info->name);
     plugin->info->summary = _(plugin->info->summary);
